---
narrator: Michael Zargham
subject: Ultimate frisbee
facilitator: Nathan Schneider
date: 2024-11-04
approved: 2024-12-02
summary: "As a sport often played with no referees, ultimate frisbee has developed a strong set of norms for addressing conflict and self-governing."
location: "East Greenbush, NY USA"
headshot: "michael-zargham.png"
topics: [frisbee, sports, organizations, dispute resolution]
---

*How do you like to introduce yourself to people as you encounter them in the world?*

I tend to introduce myself differently depending on who I'm meeting. I've lived many lives, and if we're talking about ultimate frisbee today---while it's not my primary activity now since I'm retired---I would probably talk about the teams I played for and the school I played at.

For the purpose of our conversation today, I'm Michael Zargham, a researcher and engineer, and a retired competitive ultimate frisbee player. I'm going to focus on my experiences in the ultimate frisbee communities, ranging from work on a nonprofit that operated leagues and youth outreach programs to helping found and run teams and organize tournaments. These experiences span the various practices and processes that made up the ultimate frisbee community broadly, ranging from experiences in the US to playing pickup in various countries.

*How would you outline the trajectory of your life and career in ultimate frisbee?*

When I was in high school, I played lacrosse. Lacrosse players were jerks, or at least they were jerks to me, and while I still wanted to play sports, I didn't have an overwhelmingly good experience with the social dimension of lacrosse as a sport. When I got to Dartmouth, they were out on the green throwing during orientation week, and there was a bunch of frisbee players who had led freshman trips. They were recruiting like crazy, saying "Oh, we have this great sport!" All these new people were showing up, and they were actively being friendly---like, "Oh, you want to learn how to throw a flick? Here, let me show you." All of this time and attention was spent on new folks, just showing them the ropes. They were playing pickup out on the green and hanging out with people, making it feel really welcoming. I thought, "Wow, these people are nice and they play sports. Maybe I should try this sport."

I started going to formal practices, and I was not very good. I'm small---I'm not a very tall person, and this sport favors height. There are some other confounding attributes, but for the most part, being small is not good, so being new meant not having many skills, and being small meant not having many built-in attributes to help me succeed. So I was pretty bad.

But people were encouraging despite that, and I still got to play and learn. People continued to teach me, which says a lot. Interestingly enough, because of the social aspects and because I'm an extremely overachiever type of person, I realized that I enjoyed throwing and that there were skills perpendicular to size that I could cultivate. I spent time with some of the really strong throwers on the competitive team, and I threw every day for at least an hour.

There's a thing called focused throwing, which you could think of as a skill development protocol where you throw ten flicks, ten backhands, and then as you get better, you throw high-release flicks, low-release flicks, high-release backhands, low-release backhands, inside-out flicks, inside-out backhands, outside-in flicks, outside-in backhands. As you get better, your array of throws grows, and your focus throwing regime gets bigger.

I did this for my entire first year, throwing every day, often for at least an hour, with other people who were also practicing focused throwing. I was able to develop a set of skills that sufficiently offset my size disadvantage that I was considered for the competitive team. But I did not make the competitive team in the fall---size was still an impediment.

What I did pick up from the competitive players who were teaching me to throw was the training regime. Starting the first winter, and especially the second winter, I followed the same training regime---lifting and running and the workouts that were put together for the team. By doing these training regimes in addition to the throwing regimes, by spring of my sophomore year, I made the competitive team, and I actually also made the local club team out of Burlington, Vermont. So I started playing two competitive seasons a year in my second year of playing ultimate frisbee.

The precondition for all of this was a lot of welcomingness, including people investing time, effort and attention into developing my skills, when they might have just as easily dismissed me because of my size. That was the entry point. The very idea that I could be a competitive ultimate frisbee player and play for clubs with cuts and travel schedules, both at the college level and at the adult non-college level, was probably not something anybody was thinking when I showed up on the green as this former lacrosse player who just wanted some friends.

*Before we get into the organizational side and your role in that side of the sport, I wonder if you could say a bit about the niceness you encountered and its relationship to the way that this sport operates. I played for a year or two in high school, and the thing that really stuck out to me was that there were no referees. It was a sport that, as I understand it even at the highest levels, is built on cultivating a set of practices and cultures around not requiring third-party intervention to resolve disputes. Did that have something to do with the culture you encountered?*

I think so. As a quick caveat, there are a couple dimensions we might want to come back to when we talk about some of my other experiences. But at base level, it's totally self-officiated with some specific competition regimes having augmentations. At the social level of pickup, or college competitive and club competitive (with some exceptions we'll discuss later, regarding observers), you can basically call a foul or infraction whenever you want. This means that when you're first learning, especially really competitive people tend to overdo it. They can get antsy and start making lots of calls.

What's interesting is that in your onboarding to the sport, you have to learn norms, and the norms differ based on competitive environment. I saw this when helping run youth outreach and recreational leagues in Philly---stark differences in norms depending on age group, background, or whether it was a beginner league or a more competitive league. What constituted acceptable behavior under the rules of ultimate was different.

This is one of the nice things about protocols. The rules for ultimate just say that you can call a foul if you believe an infraction has taken place. Obviously you have to know the rules, and then the person can either agree or disagree. One just says "contest" or "no-contest". The rules have a fork in them---if the person says no-contest, one thing happens; if they say contest, the other thing happens. Except in cases where people get really litigious and start arguing over what happened (which does happen), it mostly just becomes part of the flow of the game. People want to play the game, so even your own team will tell you to stand down if you're wasting time arguing.

You learn to get a feel for what is and isn't actually an infraction within your social context, learning to handle that kind of incompleteness while still using the rules. The sport attracts people who are both interested in rules and willing and able to understand and abide by them, but who won't abuse them---because you get shunned if you do. This can happen at the individual level within a team or between teams in the competitive scene. Teams that pushed the rules too far got a reputation for being "bad spirited." A team might come in second in a tournament, and people would say, "Oh yeah, but they're really bad spirited," and somehow that took away from their achievement within the social standing among the teams.

There's a strong cultural component, but I want to be careful to note that it varies widely---things that would be considered fine in one environment might be considered bad spirited in another. You see some of the worst issues when competitive and non-competitive players share an environment without adequate socialization about what's appropriate in that context.

At the college level, you're talking about hard-charging overachieving competitive people---people who got into an Ivy League University and then wanted to compete in this club sport too. When I arrived, the team had been at Nationals the year before. So it wasn't just about being nice---understanding and applying these principles of self-officiation were tantamount to success. If you couldn't do it, you couldn't play the sport.

*How did that kind of practice and culture and norms translate into the organizational structure? Were there respects in which the practices on the field were reflected in how the organizations you worked with were set up?*

The college team was a club---it did not have a coach, though we'd had volunteer coaches in the past.

*And was that by choice? Was that a sense like "we don't have referees, and we don't have coaches"?*

It was a little different. I'll talk more about coaches later since I coached for a couple of years. But at the time, it was more that there wasn't an authority figure. Even in years where the college team had a graduated player staying on to help coach, they were effectively in a support role, not an authority. You delegated certain kinds of strategic decision-making and education functions to them, and they were welcome insofar as they fulfilled those functions. It wasn't a paid role---club sports have relatively low budgets so they wouldn't really have been able to spring for a paid coach anyway.

The teams were run by captains who turned over year after year. Our team at Dartmouth almost always had two captains and a president on the men's competitive team. We also had broader cultural leadership that included the captains of the women's team. There was a kind of group-level organization because we hosted usually at least one, if not two, tournaments a year. We had a mixed tournament in the fall that was half fundraiser, half tradition. We'd show up and say, "Oh, we run a tournament in the fall. Who's going to run the tournament?" Well, I guess we're going to run the tournament---nobody else is going to run it.

A lot of it was entrenched---we had everything from cheers to organizational patterns that were just the way things were. As the class of 2007, we showed up and did what was expected: "Oh, it's our turn to do this now." The organization had to continuously turn over because, as a college team, you didn't have any continuous infrastructure at the human level. Everything was rituals and traditions, and the thing that we do, we do.

Captains generally called lines and picked teams. There were important annual rituals like tryouts and off-season training regimes, and certain tournaments were the main deciding points for who was going to try out and make the roster. There were boundaries---it wasn't just showing up to play. There was a fixed number of roster slots, someone had to decide who would get those slots, there were interviews, there were debriefs. There was quite a lot of institutional infrastructure, but it was administered by the students for the students, everything from selecting teams to coordinating travel logistics to organizing tournaments.

*How did you get into league-level organization?*

I moved to Philadelphia. The story goes: I finished at Dartmouth in 2008. I got two degrees, so I was there for five years, which allowed me to play out my full competitive college allotment. The college infrastructure is run by the USAU, and you're allowed five years of competitive play. I used all of my college-level eligibility at Dartmouth.

When I moved to Philadelphia for grad school to do a PhD in a robotics lab at the University of Pennsylvania, I had a brief hiatus with moving and relationship stuff. Then I started needing to build community---a relationship to place. I needed the same thing I needed when I went to Dartmouth: people to hang out with who were like my kind of people---smart and hardworking and capable and self-organized, all those things that I get excited about.

I found the frisbee community in Philadelphia. But now I was not a college player, so I needed to get involved differently. I started by joining the local leagues. The nonprofit that runs the local leagues in Philadelphia is called PADA, the Philadelphia Area Disc Alliance. I joined Summer League first. They have Winter League, Summer League, Fall League, Spring League---different leagues targeting different groups of people.

I started to get to know people and learn about the landscape. I figured out what the competitive teams were and started to meet people. My journey in Philly started by way of two access points: the local leagues and email listservs for workouts. Coming from a competitive background, the first thing anyone who was competitive told me was to join the listserv.

This is a very Philadelphia thing---we'd go run the stairs at the art museum. The best thing about this workout was that sometimes there'd be as many as 25 people, sometimes as few as three. There were always tourists running up the stairs making little *Rocky* gestures, while we would have an hour-and-twenty-minute workout running ladders on the stairs---up a flight, down a flight, up two flights, down two flights. We were running ourselves into the ground on these stairs, and the tourists would come by and jog up one step and do some poses. I thought it was the funniest thing because it was like the actual montage versus the movie version---we were doing the thing that the montage was of.

I got involved and started doing these workouts, and they absolutely crushed me because I had had a year off. I was so out of shape---there's no way I would have made a competitive team in Philly if I had not joined those workouts. That was in 2010 when I was starting to try out for teams, and if I hadn't been doing this listserv workout training, I'd have been out of luck. There were other things besides the stairs, but the memory of the stairs really stands out for me.

I got involved in that community, and there's a high overlap between the competitive players and the organizers. While there are far more competitive players than organizers, the people who built and maintained the competitive teams also had a really strong interest in recruiting and talent development. They had an interest in having healthy social infrastructures around the sport. They had relationships with the city of Philadelphia to get field sites---the competitive players are the ones who need fields. They're usually the ones helping organize at least the more competitive tournaments.

Sometimes you'd get retired players or people who aspire to be competitive helping build out the org infrastructure. When I was involved, maybe about half of the senior volunteer corps was still active competitive players. They often were the captains in the leagues because they were the ones teaching the more junior players. There's a cultural aspect where talented players have a relatively high norm of teaching, training, and volunteering in ways that aren't immediately obviously beneficial to them---it might benefit the team in four years, but not necessarily the team in the moment.

I think it goes back to self-officiating. There's generally a higher receptivity to norms. People would recognize and conform to norms, even if they didn't explicitly talk about them that way, because the sport itself requires that kind of awareness.

I started by playing Summer League. I agreed to be a captain because I was a strong player with background experience. I ended up on a team with two very senior competitive players---both Penn students. One was a dental graduate student, and the other was an economics person who had already graduated. I was at Penn and was a former competitive player from a recognizable school, so I got drafted early. I spent a lot of time getting engaged that first summer, and the second summer I was asked to be a captain. Getting my own experience leading a team, drafting and leading, pulled me into that whole ecosystem.

I don't remember exactly how I got sucked in deeper. I know how I got on the board, but there was a whole intermediate period which was all slippery slope. You know how people say that work accumulates to the competent? Every year over year that I spent in PADA, I had more responsibilities. I think that's a common outcome in volunteer-based organizations---they rely so much on unpaid labor to exist that there's really no other resource allocation strategy besides asking people who show up and succeed at things until they say no or stop succeeding.

That led me all the way to being on the board and actually being president of the board---just following up the "keep asking me to do stuff" path. The board is elected, not appointed. I didn't actually want to run for the board---a bunch of people put me up to it, and I said, "Oh fine, there's no way they're going to elect me." And they did. So long story short, I fell up through levels of engagement in that community just by showing up and being willing, then delivering on the stuff I agreed to do.

*How does leading this organization work? How does it compare to other organizations you've been in? You've also founded a company and served on other boards. What were some of the peculiarities of governance in the context of ultimate frisbee?*

At the time I thought it was an utter mess. It was my first experience in formal accountability. I was president of the PADA board in my first term, also not something I wanted. I think I was put there partly to help deal with a situation which I won't go too far into, but it involved people overstating their expertise and authority. This is an environment where you've got artists and teachers and engineers and lawyers and doctors all mixed together, and board composition can be pretty different at any given time. There was a lawyer in a relatively senior position that many people felt no one could argue with effectively. I'm pretty sure I ended up on the board to argue with this guy---that was apparently why the community elected me, for my ability to argue.

In practice, what I did was almost entirely dispute resolution. The organization ran quite well, and looking back now, with experience in open source software, research nonprofit governance, forming an engineering firm, and helping early tech startups---it turns out it wasn't all that messy. It was actually remarkably contained given the diversity of stakeholders served, the physical geographic distribution, and the variety of activities undertaken. By all reasonable complexity measures I've encountered since then, it was amazingly well-organized.

I spent quite a lot of time on the phone, usually reflecting what I thought were steel-manned versions of other people's positions back to each other to diffuse situations. I had to do some agenda setting, but that organization was already about 30 years old, and like my experience with frisbee at Dartmouth, there was a lot of "the way things were done" already established. It had annealed, stabilized itself.

I dealt with some interesting challenges, like our relationship with the cricket club. We shared physical field space with them, and as president, I also had to sit on another board---the board of cricket and ultimate. This entity existed solely to be the container of the two organizations for dealing with city contracts because we were sharing stewardship of the field site. We had a historic clubhouse, this beautiful field site, and the legal interoperability required this other board.

That was a strange, bespoke artifact---suddenly being told, "Oh, you're on this other board too now, good luck!" We didn't have to do much, but we did have meetings about repairs because this building had very specific requirements around what you could do to it. We had to take care of it in certain ways.

But in terms of the social stuff, it was almost entirely mediating dispute resolution and presiding over board meetings. The org had a lot of inertia, and challenges arose more when things wanted to change than from maintaining existing operations.

*At the time you were studying engineering and developing a career as an engineer. How did these two modes of thinking intersect? How did engineering overlap in your mind, and maybe in others' minds, with the nature of the sport and the organizations around it?*

Starting around 2005 or 2006, I was working on flocking coordination, multi-agent consensus problems---basically multi-agent coordination problems in robotics. So literally, the subset of robotics which was entirely about algorithms and rules and protocols for coordinating distributed activities with distinct agents.

It wasn't a big leap for me. In fact, I almost didn't think about it much because I was used to thinking in terms of a bunch of individual actors using protocols to coordinate their activities. My dissertation was on distributed optimization strategies in networks with constrained resources. Any economic or operational problem reduces in some form to a network of actors, both individual and coordination loci---entities or organizations or teams---and then they have decision-making that affects each other.

As that was the subject of my engineering work, being involved in founding teams, playing on teams, line calling, team roster selection, as well as figuring out how to get resources set up for leagues---all these roles fit together into a structure that got things done. From my perspective, these were extremely complementary in hindsight, though at the time I didn't think about it at all. I just did both things, and I could do both things. The fact that one was the social dimension and one was the technical dimension---I definitely benefited from that by seeing through both lenses.

*How long were you actively involved in the sport?*

About 15 years, all told. I started playing ultimate in 2003. I started in Philly in 2009, so 15 years ago, and I think I was on the board from 2012 to 2014. I graduated from my PhD in 2014, so I must have been on the board 2012 through 2014. That sounds right.

I didn't stay on. It was a lot of work. Being in grad school made it possible to do the work at the level I was doing it. After two years I stepped down, but I helped onboard the new president and other stuff. I couldn't carry that level of unpaid labor outside of grad school. I moved into a full-time job, was still teaching at Penn, and in 2015, I had also blown out my knee. I wasn't able to play competitively anymore.

This was a very difficult and challenging time for me. So much of my identity was built around competitive ultimate frisbee. When I shattered my knee in summer of 2014, I got hit from behind---somebody who was a young, talented, athletic player, mistakenly believing that the tiny little guy could not jump up and catch that frisbee, dove for it and hit me in the back. I caught it and landed on the ground. We tilted forward and I shattered my left knee---ACL, MCL, both sides of my meniscus.

That was pretty devastating. At the time I was playing for the men's competitive team out of Philly. I was recruiting and team-building too, so I was already deeply involved. I was effectively the defensive coordinator---not a captain, but the person who organized the defensive squad. And suddenly I couldn't play. There was no way---I went to the doctor, I was going to need surgery, it was going to be who knows how long before I could play again at all.

But my team sufficiently valued my non-field contributions that they asked me to stay on and continue to be the defensive coordinator. So I became the D-line coach. The player part of my role evaporated---I didn't have a roster spot anymore, which made sense because I couldn't play. But I transmuted from D-line coordinator-player to D-line coach in a matter of a month. Once it came out that I wasn't going to be able to play, my team was like, "Cool, you can't leave." I was like, "Wait, what?" I thought I was out, but they were basically like, "No, no, you're not---you do not have our permission to leave just because you blew out your knee. We need you."

That was my last competitive season---2014---and I only made it through to June or maybe July. It was pretty depressing but cushioned to some extent by my team refusing to relinquish me. I actually stayed on as coach of that team for three years until I moved to California.

That's an important cultural aspect---while the game is obviously being played on the field, coaches are uncommon. They're more common now---in fact, most competitive teams do have coaches, but they're not paid staff for the most part. They're members of the team that come into their roles by invitation. I have a friend up here in Albany who's currently coaching a women's team in New York City, and he had to go through a very rigorous tryout process. He's an extremely talented player who played in the championship game five times---great guy---but he has also been teaching and training. I can't help but emphasize that even though coaches are really common in competitive ultimate now, it's like a roster spot---the team has to pick you. If anything, the captains have more authority than the coaches.

*Are there contexts when you saw the sport confronting what we might think of as capture? That is, attempts to take over the sport, to co-opt some of its norms?*

There was a largely failed corporate takeover, this is good. Philly was actually one of the main sites of the founding of the MLU---Major League Ultimate---which the Philadelphia Spinners won. But let me backtrack first. There was the AUDL---American Ultimate Disc League---which still exists. The AUDL was run very unprofessionally, at least in the first year it was a mess. A bunch of the Philly players played for the Spinners in the inaugural season of the AUDL.

I did not play on that team. I was too involved in other things---I didn't even try out. I was like, "Whatever, professional frisbee is going to be dumb." A bunch of my friends did play, and they actually won the first season of the AUDL as the Philly Spinners. But the whole league organization was kind of shitty, and then somebody---I think a coach from this scene---took it upon themselves to drive the MLU.

The second year, Philly was in the MLU. I played for that team one year, I think in their third or fourth year when they had enough momentum. As a community, we decided that while people hated the term "semi-pro," this was a great place for resources and training. But they didn't pay super well, the stands were reasonably well attended but mostly by our friends, and it was a weird vibe. They had refs, they had a slightly bigger field, and they really shot themselves in the foot by trying to use a different disc.

There's almost nothing more sacred to a frisbee player than using the right disc. Never hand them a Wham-O---it's a Discraft Ultra-Star 175 gram. Do not mess with that. If you mess with that, you're immediately out---you're not part of the real frisbee crew, that's not a real disc.

The semi-pro leagues rolled in competing with the clubs for talent, but the clubs basically owned all the hearts and minds. The semi-pro leagues got subjugated to the clubs except in second-tier cities that didn't have good competitive clubs. Even today, if you look at the AUDL, which still exists, its main home turf is in places that don't rate in the club series. The club sport is still the dominant form of achievement, and the semi-pro leagues appear and stabilize in places that are under-served by the club scene. Maybe in some cases they're routing resources to people who would not have otherwise gotten to compete. I've heard there's been some success in the semi-pro world with the women's sport, but I haven't followed it closely.

It's a little bit painful to reminisce about it with the whole knee injury thing. But there was this attempt, this belief that capitalization of the sport could work because it has huge reach, so many players, so much enthusiasm and love. These leagues spawned up, but my impression was that they just couldn't win the hearts and minds of the people who are the backbone of the ultimate frisbee community.

*It's fascinating that the semi-pro is regarded as under the club. What do you think contributed to that resiliency against an attempted takeover?*

I think it could have gone either way. On one hand, I think the capitalist mentality just couldn't see what everyone loved about it. They inadvertently squashed things and didn't focus on things that were part of the real value. If they had been even a little more aware---not that you would expect them to have been---but if they had been a little more aware of the intangible forms of value that were created and stewarded within these communities, they could have made more space for them and possibly had more success.

Conversely, you had all this self-organization, and people were just like, "Yeah, but the way they do it sucks---we get to decide. Let's just keep doing it our way." They might have actually done a good enough job and offered a materially better value proposition. Because it's worth noting that a competitive ultimate frisbee player is out several thousand dollars a year. Some of them subsidize the cost of people who couldn't afford it, because you didn't want to cut people from your team just because they couldn't afford to go to tournaments. If you're on the team, it's now a team-level problem, not an individual-level problem.

So you're out thousands of dollars a year if you're on a competitive ultimate frisbee team, in addition to a lot of your weekends and evenings and all sorts of commitments. The way the semi-pro teams approached this was to try to offset some of those costs, as if that was what mattered. But if you look at it from an economics view, that completely discounts a ton of intangible sources of value. They thought they'd made it better because you don't have to pay $5,000 or whatever---"We solved that problem, we can successfully provision our team." We had been provisioning ourselves for years. If you're provisioning us, great, I appreciate not having to pay that. But if in the process you're taking away a lot of the other intangible value, then it's not going to cut it.

What happened was that a lot of people would play in the semi-pro season during the preseason period, but then they would prioritize their clubs come midsummer. They'd play to get the resources and training, but when push came to shove, the prestige stayed on the club side. It had history, it had norms. I think it goes back to the point that these were actually relatively mature institutions. They're not new. The incumbents were the clubs, the clubs were prestigious, and even in cases where the club's name turned over, you could trace the community basis.

Take PADA---PADA is old. But the teams I played for had turnovers in names. The old school Philly team was called Rage, and after Rage there was Southpaw. Southpaw only lasted for two or three years because it had this coach who was super rigid in certain ways that just didn't jive for people, and the team imploded. Then after a hiatus, they formed Patrol, which was the team that I helped organize and played on. That team turned over too---I forget the name of the Philly team now. But there's still cultural continuity within the competitive scene in Philly.

Running in parallel, there's the women's team, which was Green Means Go when I was there. I'm not sure what it is now, but they had their own lineage. And then there were mixed teams---one of the longest-standing Philadelphia teams which still exists today is called AMP. I played for AMP in 2010. AMP has since won a national championship. AMP is almost twenty years old now---it was the mixed team in Philly. They were over five years old when I played for them, probably closer to ten, and they still exist. So that gives you a sense---it's a twenty-plus-year-old mixed club frisbee team in Philly.

Actually, my COO at BlockScience---he joined later, he's not technically a co-founder---is a former teammate of mine from Philly Ultimate. He's a professional mechanical engineer who worked for the Army Corps of Engineers and had his own completely separate life that I barely knew about. But the ultimate frisbee connection is how I knew him. I used to play against him, used to cover him in practice. He also played for AMP and for Patrol.

Just as a point of reference, much of BlockScience's coordination infrastructure---our ops---is people who were part of that same scene. That means a lot of the norms we've been talking about got transferred across contexts. When ops are breaking down or inefficient, the running inside joke is basically like, "Man, we're worse than frisbee teams at logistics or operations." And that's because AMP's logistics and operations were so tight, entirely on a volunteer basis, that there's so much commonality in the community that you can just say, "We're worse than a frisbee team!"

*When you were involved at the organizational level, did you run into challenges around your relationship with those norms and that culture? Did you have experiences where you ran the risk of doing harm to the sport's culture in trying to bureaucratize or systematize?*

That's a good question. I'm going to say I did not have that problem. I think some people did. This goes back to my answer before---the fact that as an engineer I'm focused on multi-agent systems meant that I had a much higher expectation of distributed locus of decision-making and heterogeneity than most people who would come in and systematize things. So I actually didn't systematize much frisbee stuff. When I did, it was out of necessity and in a minimalist frame.

This might not be obvious about me, because I'm an engineer and I work on a lot of complex systems. People see what I do and sometimes think I'm approaching it from a "structure is good" perspective. I'm actually kind of the opposite---I want as little structure as possible. I also want the thing to work, and my experience in life has been that most people take a really idealistic view of this. They either overdo or underdo structure, but don't have the register for figuring out how to satisfice---enough, but no more.

That's a tricky skill. There was lots of political stuff to deal with, but it was way more that than the structural stuff. The political stuff would come up when you're responsible for calling lines, or building rosters, or setting up a program, or figuring out who the coordinators for Summer League are going to be. There are all these very social dimensions, and whenever anything is dependent on norms, there's always going to be room for politics---little-p politics.

Most of the difficulties were because the ultimate frisbee community as a whole is norm-heavy relative to structure or rule-heavy. In the technical world, people tend to go heavy on rules because they think it's going to eliminate politics---hint: it doesn't. But we think it does, or people tend to adopt narratives that say it does. In frisbee land, the rules are pretty fixed because there's the actual rulebook, and you're working from something that has those rules, but also has a concept of "spirit of the game." I would be remiss not to bring this up---the ultimate frisbee rulebook basically has a rule that supersedes the rules in the front of it. The spirit of the game rule is really important because it essentially privileges the norms above the rules.

That contributes to some of the cultural aspects, but it also creates some of the politics I mentioned before. You'll be in Summer League, and you'll have a beginner-ish player, or someone who's only acclimated to low-level pickup or certain kinds of low-level club, less competitive, whose idea of an infraction is "you touched me"---when it's impossible to play a sport without incidental contact. You get these challenges where different norms from different contexts butt up against each other.

This is partly why being a leader within this community is mostly about dispute resolution---essentially mediating when the rules themselves don't mediate well enough. You get someone calling "foul" and someone else saying "that's not a foul" and then "you're being bad spirited," and it devolves quickly. Whether you're the captain of a Summer League team, a league coordinator, or the board president, your job is basically to de-escalate wherever this happens. Because the rules are so flexible, it's really easy for people to have genuine, conflicting opinions and just default to "you're bad" and "the spirit is more important, and you're being bad spirited." You can see how it enables that kind of impasse, but that puts a burden on the community leadership, regardless of whether it's competitive sport or leagues, to de-escalate because these issues are always going to happen. They can't not happen.

Related to this, I mentioned observers earlier. In competitive ultimate, observers basically take on that de-escalation responsibility in competitive play. When you get to the finals at regionals, or at nationals---at least in the winners' bracket---you'll see observers. When I was there, there were only enough observers to spot-cover games at nationals, but observers had a passive role. They only had two kinds of active calls: offsides and line calls---basically in-bounds/out-of-bounds type calls. This is because it's almost impossible for anyone else who's not dedicated to that to have a good perspective on it. There are a lot of arguments about in or out, and it's almost impossible to watch your own offsides when you're pulling (that is when throwing off to the other team).

Otherwise, the way self-officiation could escalate is you could do the normal workflow, but you could also escalate to the observer, at which point if either person escalated, they got to make the call. But the observer is only a failover---the primary mechanism is still "foul" or "travel", "contest" or "no-contest". This creates a second layer to reduce the risk of abuse. I view this as helpful---it adds an extra normative bit because in cases where things are going smoothly, you basically never go to the observer. But in a game where there's genuine conflict about what is and isn't appropriate---maybe you've got a West Coast team playing an East Coast team with sufficiently different cultural expectations---the observer is the de-escalation point. You can just say, "Fine, go to the observer," and they make a judgment call.

There are observer training programs which are also self-organized. You built in this extra backstop, and I view it as more in common with what I was saying before---you've got the rules, you've got the norms, and then inevitably you have the natural evolution of problems that need to be de-escalated or mediated. The observer is in some ways like a mediator on standby, which is helpful as you get to these increasingly competitive levels where people have been training for nine months and they're at the semifinals of nationals. Just knowing the observers are there helps, but I think they did a good job not usurping the authority of self-officiation. This ties back to the pros where they were like, "No, we're going to do refs," and it changed everything. The observers were essentially the equivalent of seeing the problem and solving it with an ultimate native solution, instead of seeing the problem and trying to paste on something from another culture.

*Finally, what lessons do you think ultimate frisbee has to offer the world? What do these protocols teach us that could be applicable in other domains?*

At a basic level, sports in general can teach us a lot about how to work together and achieve collective outcomes. Given what I said about not enjoying lacrosse and then going to ultimate, obviously ultimate does that in a way that I found more culturally palatable.

Let me break this into two parts---first, what I learned personally, and second, what I think the world can learn, because I need this bridge. For me, I learned very much how to deal with other humans. I'm extremely on the spectrum in ways that I think are good but also make it really hard for me to deal with people in general. I do not think I would be able to have healthy social relationships if I had not gone through this experience. I haven't encountered another environment that inculturated me to dealing with other humans in a way that works for me.

What I mean is that it has rules, protocols, reliability, expectations, outcomes, delegation of authority, accountability for your actions---all that kind of rigorous structure you need to perform---but then allowed you to pursue performance in an environment that wasn't toxic. So many environments I've encountered that are performance-oriented achieve their goals through toxicity or through things that feel toxic to me. Since I am extremely drawn to performance, effectiveness, capability, reliability---things that require structure to create reliable outcomes out of unreliable parts---this was crucial. You cannot do it without structure. But because so many regimes for imposing structure are culturally toxic or have toxic side effects, it would have been an issue.

I feel like I'm in the place I am today in part because of experiences I had in ultimate. Being trusted and then being accountable for what you take on, whether it's taking a throw that's a little too hard that you maybe shouldn't have thrown, or making calls as a coach. Actually, maybe this is an important story---one I tell the most about my experience coaching ultimate.

When I was the defensive coordinator of that club team, I had no official authority as the coach. The players and captains could override anything I said. We were at the semifinals of regionals where only the top two teams would qualify for nationals. There was a backdoor bracket, and the team that was best in the country at the time was out of DC. We were in Philly, pretty evenly matched with the team from Pittsburgh, playing them in the semifinals.

In a close match, I played open rotation, not subbing to win. I got questioned repeatedly throughout the game. It was like 11-11, 12-12, and we lost that game 15-13. They were pissed---"Why did you do that?" I said, "Trust me---you gave me this job. You want to go to nationals. You don't want to win this game, you want to go to nationals."

We lost. We went to the backdoor bracket while Pittsburgh went and played DC. They got destroyed---DC was very good. We went through the backdoor bracket, played back up to face Pittsburgh again, and we stomped them because they were exhausted. They had played to win against us, played to win against DC, then showed up to play us again. We had played open rotation, gone through our backdoor bracket with open rotation, and when we finally got to the team that was actually our peer, we hadn't gotten anyone injured or worn out. We had our entire roster ready to go in the game that mattered, and we just dominated them.

That period between games---it was a day apart, from the end of one day to the end of the next---was a little icy. People were not happy. I remember just saying, "We put together the strategy, you asked me to call it, I held the line. This was the strategy, we followed it, it's going to pay off." And it did. Obviously it could have gone the other way, but the fact is---and this is almost more important than that it worked out---they stuck to it. Nobody was happy about it when I wasn't calling the tight lines. There was nothing stopping them---it wouldn't have even been a mutiny because it wasn't actually up to me, really. But they did it anyway, even though they didn't want to.

Everyone was thrilled when we won the game and went to nationals that year. But there's something about this difference between authority and trust that I can't quite put my finger on. That's been another important anecdote for me because it affects the way I approach leadership in any other context. Leadership isn't telling you what you have to do---leadership is getting you to do what you need to do, even when you don't want to, even when I don't have the authority to make you do it.

The final answer---what I think the world has to learn---is broadly that you can do more with culture and norms than I think a lot of people give credit for. I know that a lot of people know those things are valuable, but if they're coming back to me as an engineer and leader, I think a lot of people put too much emphasis on rules and tools and not enough on norms and practices. If there's anything that ultimate frisbee can teach people, especially high performers who want to achieve things, it's that having a healthy set of cultures and norms and practices and rituals isn't just helpful for achieving success---it's necessary. It's not sufficient, but it's necessary. No amount of tools and rules can compensate for healthy cultural practices.
